@@ -63,9 +63,12 @@ ci.glm <- function(x,
                    ...) {
   method <- match.arg(method, choices = c("profile", "wald", "normal", "residual"))
 
+  # No robust vcov for profile method
   if (method == "profile") {
     if (!is.null(vcov) || !is.null(vcov_args) && isTRUE(verbose)) {
-      warning(insight::format_message("The `vcov` and `vcov_args` are not available with `method = \"profile\"`"), call. = FALSE)
+      warning(insight::format_message(
+        "The `vcov` and `vcov_args` are not available with `method = \"profile\"`"
+      ), call. = FALSE)
     }
     out <- lapply(ci, function(i) .ci_profiled(model = x, ci = i))
     out <- do.call(rbind, out)
@@ -82,6 +85,7 @@ ci.glm <- function(x,
     )
   }
 
+  # Return the CI bounds as a data frame.
   row.names(out) <- NULL
   out
 }
