@@ -79,8 +79,6 @@ model_parameters.stanreg <- function(model,
                                      parameters = keep,
                                      verbose = TRUE,
                                      ...) {
-
-
   # Processing
   params <- .extract_parameters_bayesian(
     model,
@@ -108,9 +106,9 @@ model_parameters.stanreg <- function(model,
   }
 
   params <- .add_pretty_names(params, model)
-  if (isTRUE(exponentiate) || identical(exponentiate, "nongaussian")) {
-    params <- .exponentiate_parameters(params, model, exponentiate)
-  }
+
+  # exponentiate coefficients and SE/CI, if requested
+  params <- .exponentiate_parameters(params, model, exponentiate)
 
   params <- .add_model_parameters_attributes(
     params,
@@ -149,8 +147,6 @@ model_parameters.stanmvreg <- function(model,
                                        parameters = keep,
                                        verbose = TRUE,
                                        ...) {
-
-
   # Processing
   params <- .extract_parameters_bayesian(
     model,
