@@ -62,13 +62,19 @@ print_md.parameters_model <- function(x,
   }
 
   # footer
-  footer <- .print_footer(
+  footer_stats <- .print_footer(
     x,
     digits = footer_digits,
     show_sigma = show_sigma,
     show_formula = show_formula,
     format = "markdown"
   )
+  if (!is.null(footer)) {
+    footer <- paste0("\n", footer, "\n", footer_stats)
+  } else {
+    footer <- footer_stats
+  }
+
 
   insight::export_table(
     formatted_table,
