@@ -36,6 +36,9 @@
     x[[param_col]] <- insight::trim_ws(paste0(x[[param_col]], linesep, "(", x$SE, ")"))
     x <- x[c(param_col, "p")]
     colnames(x) <- paste0(colnames(x), " (", modelname, ")")
+  } else if (style %in% c("est", "coef")) {
+    x <- x[1]
+    colnames(x) <- paste0(colnames(x), " (", modelname, ")")
   }
   x[[1]][x[[1]] == "()"] <- ""
   x
@@ -149,7 +152,7 @@
 # that contain the random effects or zero-inflated parameters
 
 .all_coefficient_types <- function() {
-  c("Odds Ratio", "Risk Ratio", "IRR", "Log-Odds", "Log-Mean", "Probability", "Marginal Means", "Estimated Counts", "Ratio")
+  c("Odds Ratio", "Risk Ratio", "Prevalence Ratio", "IRR", "Log-Odds", "Log-Mean", "Log-Ratio", "Log-Prevalence", "Probability", "Marginal Means", "Estimated Counts", "Ratio")
 }
 
 
@@ -331,7 +334,6 @@
   indent_parameters <- NULL
 
   if (is.list(groups)) {
-
     # find parameter names and replace by rowindex
     group_rows <- lapply(groups, function(i) {
       if (is.character(i)) {
@@ -370,7 +372,6 @@
     }
     names(groups) <- names(group_rows)
   } else {
-
     # find parameter names and replace by rowindex
     group_names <- names(groups)
     groups <- match(groups, x$Parameter)
@@ -604,7 +605,6 @@
 
 
   for (type in names(tables)) {
-
     # do we have emmeans emlist? and contrasts?
     model_class <- attributes(tables[[type]])$model_class
     em_list_coef_name <- (!is.null(model_class) && "emm_list" %in% model_class &&
@@ -722,7 +722,7 @@
     }
 
     table_caption <- NULL
-    if (is.null(format) || format == "text") {
+    if (is.null(format) || format %in% c("markdown", "text")) {
       # Print
       if (component_header$name != "rewb-contextual") {
         table_caption <- c(sprintf("# %s %s", component_header$subheader1, tolower(component_header$subheader2)), "blue")
