@@ -1,6 +1,7 @@
 .runThisTest <- Sys.getenv("RunAllparametersTests") == "yes"
 
-if (.runThisTest && requiet("testthat") && requiet("cgam") && utils::packageVersion("insight") > "0.14.4") {
+if (.runThisTest && requiet("testthat") && requiet("cgam") && 
+    utils::packageVersion("insight") > "0.18.0") {
   test_that("model_parameters - cgam", {
     # cgam -----------------------
 
@@ -14,15 +15,20 @@ if (.runThisTest && requiet("testthat") && requiet("cgam") && utils::packageVers
     expect_equal(
       df_cgam,
       structure(list(
-        Parameter = "(Intercept)", Coefficient = 1.187, SE = 0.3054,
-        CI = 0.95, CI_low = 0.569520101908619, CI_high = 1.80447989809138,
-        t = 3.8868, df_error = 39.5, p = 4e-04),
+        Parameter = "(Intercept)",
+        Coefficient = 1.187,
+        SE = 0.3054,
+        CI = 0.95,
+        CI_low = 0.569520101908619,
+        CI_high = 1.80447989809138,
+        t = 3.8868,
+        df_error = 39.5,
+        p = 4e-04),
         row.names = c(NA, -1L),
         sigma = 2.15946395506817,
         residual_df = 39.5,
         pretty_names = c(`(Intercept)` = "(Intercept)"),
         ci = 0.95,
-        test_statistic = "t-statistic",
         verbose = TRUE,
         exponentiate = FALSE,
         ordinal_model = FALSE,
@@ -36,6 +42,10 @@ if (.runThisTest && requiet("testthat") && requiet("cgam") && utils::packageVers
         ignore_group = TRUE,
         ran_pars = TRUE,
         show_summary = FALSE,
+        log_link = FALSE,
+        test_statistic = "t-statistic",
+        log_response = FALSE,
+        log_predictors = FALSE,
         weighted_nobs = 50,
         model_formula = "y ~ incr.conv(x)",
         coefficient_name = "Coefficient",
@@ -91,39 +101,40 @@ if (.runThisTest && requiet("testthat") && requiet("cgam") && utils::packageVers
 
     df <- suppressWarnings(parameters::model_parameters(ans))
 
-    expect_equal(df,
+    expect_equal(
+      df,
       structure(
         list(
-          Parameter = "(Intercept)",
-          Coefficient = 5.5174,
-          SE = 0.3631,
-          CI = 0.95,
-          CI_low = 4.80573707721351,
-          CI_high = 6.22906292278649,
-          t = 15.1954,
-          df_error = 890.4,
-          p = 0
+          Parameter = c("(Intercept)", "s.incr(x)"),
+          Coefficient = c(5.5174,NA),
+          SE = c(0.3631, NA),
+          CI = c(0.95, NA),
+          CI_low = c(4.80476838465533, NA),
+          CI_high = c(6.23003161534467, NA),
+          `t / F` = c(15.1954, NA),
+          df = c(NA, 8.4),
+          df_error = c(890.4, NA),
+          p = c(0, 0),
+          Component = c("conditional", "smooth_terms")
         ),
-        row.names = 1L,
-        sigma = numeric(0),
-        residual_df = 890,
+        row.names = c(NA, -2L),
         ci = 0.95,
-        test_statistic = "t-statistic",
         verbose = TRUE,
         exponentiate = FALSE,
         ordinal_model = FALSE,
         linear_model = TRUE,
         mixed_model = TRUE,
-        model_class = c(
-          "cgamm",
-          "cgam"
-        ),
+        model_class = c("cgamm", "cgam", "lmer"),
         bootstrap = FALSE,
         iterations = 1000,
         robust_vcov = FALSE,
         ignore_group = TRUE,
         ran_pars = TRUE,
         show_summary = FALSE,
+        log_link = FALSE,
+        test_statistic = "t-statistic",
+        log_response = FALSE,
+        log_predictors = FALSE,
         model_formula = "y ~ s.incr(x)",
         coefficient_name = "Coefficient",
         zi_coefficient_name = "Log-Odds",
@@ -131,9 +142,7 @@ if (.runThisTest && requiet("testthat") && requiet("cgam") && utils::packageVers
         ci_digits = 2,
         p_digits = 3,
         footer_digits = 3,
-        class = c("parameters_model", "see_parameters_model", "data.frame"),
-        object_name = "ans"
-      ),
+        class = c("parameters_model", "see_parameters_model", "data.frame"), object_name = "ans"),
       tolerance = 0.01
     )
   })
