@@ -3,24 +3,23 @@
 if (.runThisTest &&
   requiet("testthat") &&
   requiet("parameters") &&
-  requiet("tripack") &&
   requiet("insight") &&
   requiet("quantreg")) {
-
+  
   # rqss ---------
 
-  data("CobarOre")
-  set.seed(123)
-  CobarOre$w <- rnorm(nrow(CobarOre))
-  m1 <- rqss(z ~ w + qss(cbind(x, y), lambda = .08), data = CobarOre)
+  # data("CobarOre")
+  # set.seed(123)
+  # CobarOre$w <- rnorm(nrow(CobarOre))
+  # m1 <- rqss(z ~ w + qss(cbind(x, y), lambda = .08), data = CobarOre)
 
-  mp <- suppressWarnings(model_parameters(m1))
-  test_that("mp_rqss", {
-    expect_identical(mp$Parameter, c("(Intercept)", "w", "cbind(x, y)"))
-    expect_equal(mp$Coefficient, c(17.63057, 1.12506, NA), tolerance = 1e-3)
-    expect_equal(mp$df_error, c(15, 15, NA), tolerance = 1e-3)
-    expect_equal(mp[["df"]], c(NA, NA, 70), tolerance = 1e-3)
-  })
+  # mp <- suppressWarnings(model_parameters(m1))
+  # test_that("mp_rqss", {
+  #   expect_identical(mp$Parameter, c("(Intercept)", "w", "cbind(x, y)"))
+  #   expect_equal(mp$Coefficient, c(17.63057, 1.12506, NA), tolerance = 1e-3)
+  #   expect_equal(mp$df_error, c(15, 15, NA), tolerance = 1e-3)
+  #   expect_equal(mp[["df"]], c(NA, NA, 70), tolerance = 1e-3)
+  # })
 
 
   # rq ---------
